/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                    TERCER GRADO DE SECUNDARIA (Excale 09)
/*
/*                          **** CONTEXTO ****
/*
/*                     Ciclo escolar evaluado: 2007 - 2008
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE CONTEXTO
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale09_2008_Alum_Cuest.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale09_2008_Alum_Cuest.txt
/*         as como el archivo Excale09_2008_Alum_Cuest.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale09_2008_Alum_Cuest.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale09_2008_Alum_Cuest.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 16 DE MARZO DEL 2010
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale09_2008_Alum_Cuest.TXT";

PROC FORMAT;
     VALUE id_entF     1         = "Aguascalientes"
                       2         = "Baja California"
                       3         = "Baja California Sur"
                       4         = "Campeche"
                       5         = "Coahuila"
                       6         = "Colima"
                       7         = "Chiapas"
                       8         = "Chihuahua"
                       9         = "Distrito Federal"
                       10        = "Durango"
                       11        = "Guanajuato"
                       12        = "Guerrero"
                       13        = "Hidalgo"
                       14        = "Jalisco"
                       15        = "Mxico"
                       16        = "Michoacn"
                       17        = "Morelos"
                       18        = "Nayarit"
                       19        = "Nuevo Len"
                       20        = "Oaxaca"
                       21        = "Puebla"
                       22        = "Quertaro"
                       23        = "Quintana Roo"
                       24        = "San Luis Potos"
                       25        = "Sinaloa"
                       26        = "Sonora"
                       27        = "Tabasco"
                       28        = "Tamaulipas"
                       29        = "Tlaxcala"
                       30        = "Veracruz"
                       31        = "Yucatn"
                       32        = "Zacatecas";
     VALUE id_modF     1         = "Urbana Pblica"
                       2         = "Rural Pblica"
                       3         = "Educacin Indgena"
                       4         = "Curso Comunitario"
                       5         = "Privada"
                       6         = "General"
                       7         = "Tcnica"
                       8         = "Telesecundaria"
                       9         = "Privada";
     VALUE $modF       "GRAL"    = "General"
                       "TEC"     = "Tcnica"
                       "TV"      = "Telesecundaria"
                       "PRIV"    = "Privada";
     VALUE $mageb05f   "R"       = "Escuela rural"
                       "UA"      = "Escuela urbana de alta marginacin"
                       "UB"      = "Escuela urbana de baja marginacin"
                       "NA"      = "No aplica";
     VALUE sexoF       1         = "Hombre"
                       2         = "Mujer"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE edadF       99        = "Respuesta omitida";
     VALUE edadcF      1         = "14 aos o menos"
                       2         = "15 aos"
                       3         = "16 aos"
                       4         = "17 aos o ms"
                       9         = "Respuesta omitida";
     VALUE edadnF      1         = "Edad normativa"
                       2         = "Extra-edad"
                       9         = "Respuesta omitida";
     VALUE edad_acF    98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE mes_nacF    1         = "Enero"
                       2         = "Febrero"
                       3         = "Marzo"
                       4         = "Abril"
                       5         = "Mayo"
                       6         = "Junio"
                       7         = "Julio"
                       8         = "Agosto"
                       9         = "Septiembre"
                       10        = "Octubre"
                       11        = "Noviembre"
                       12        = "Diciembre"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE docenteF    99999     = "Respuesta omitida";
     VALUE as1_2F      1         = "El espaol"
                       2         = "Una lengua indgena (nhuatl, maya, purpecha, mixteco, otom u otra)"
                       3         = "Un idioma extranjero (francs, ingls, alemn u otro)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as003F      1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as004F      0         = "Con ninguno de los dos"
                       1         = "Con mi pap"
                       2         = "Con mi mam"
                       3         = "Con mi pap y mi mam"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as5_7F      1         = "Nunca o casi nunca"
                       2         = "Pocas veces"
                       3         = "Frecuentemente"
                       4         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as008F      0         = "No hice las tareas"
                       1         = "Algunas de las tareas"
                       2         = "La mayora de las tareas"
                       3         = "Todas las tareas"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AS009F      0         = "No hago tareas ni estudio"
                       1         = "1 da"
                       2         = "2  3 das"
                       3         = "4  5 das"
                       4         = "6  7 das"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AS010F      0         = "No hago tareas ni estudio"
                       1         = "1 hora o menos"
                       2         = "2 horas"
                       3         = "3 horas"
                       4         = "4 horas o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AS011F      1         = "De 0 a 5"
                       2         = "Entre 6 y 10"
                       3         = "Entre 11 y 15"
                       4         = "Entre 16 y 20"
                       5         = "21 pginas o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as12_16F    1         = "Nunca o casi nunca"
                       2         = "Pocas veces"
                       3         = "Frecuentemente"
                       4         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as017F      0         = "No ayud"
                       1         = "Menos de 1 hora por da"
                       2         = "De 1 a 2 horas por da"
                       3         = "3 horas o ms por da"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as018F      0         = "No lo hago"
                       1         = "1 da a la semana"
                       2         = "2  3 das a la semana"
                       3         = "4 das o ms a la semana"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as019F      0         = "Pblica"
                       1         = "Privada"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as020F      1         = "Indgena"
                       2         = "Rural (en una pequea comunidad)"
                       3         = "Una escuela del Conafe (Curso comunitario)"
                       4         = "Urbana (en una ciudad)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as021F      1         = "Un mismo maestro daba clases a alumnos de diferentes grados"
                       2         = "Haba un maestro para cada grado escolar"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as022F      1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as023F      0         = "Ninguno"
                       1         = "1 ao"
                       2         = "2 aos o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as024F      0         = "Ninguno"
                       1         = "Primero"
                       2         = "Segundo"
                       3         = "Tercero"
                       4         = "Cuarto"
                       5         = "Quinto"
                       6         = "Sexto"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as025F      0         = "Ninguna"
                       1         = "De 1 a 2"
                       2         = "De 3 a 4"
                       3         = "5 materias o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as026F      1         = "Nunca o casi nunca"
                       2         = "Pocas veces"
                       3         = "Frecuentemente"
                       4         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as027F      0         = "No lo he hecho"
                       4         = "10 aos o menos"
                       3         = "11 aos"
                       2         = "12 aos"
                       1         = "14 aos o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as028F      1         = "Nunca o casi nunca"
                       2         = "Pocas veces"
                       3         = "Frecuentemente"
                       4         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as029F      0         = "No lo he fumado"
                       4         = "10 aos o menos"
                       3         = "11 aos"
                       2         = "12 aos"
                       1         = "14 aos o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as030F      1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as31_36F    0         = "Nunca o casi nunca"
                       1         = "Pocas veces"
                       2         = "Frecuentemente"
                       3         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as037F      1         = "Secundaria"
                       2         = "Bachillerato o preparatoria"
                       3         = "Carrera tcnica"
                       4         = "licenciatura (carrera universitaria)"
                       5         = "Posgrado (maestra o doctorado)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as038F      0         = "No s"
                       1         = "Secundaria"
                       2         = "Bachillerato o preparatoria"
                       3         = "Carrera tcnica"
                       4         = "licenciatura (carrera universitaria)"
                       5         = "Posgrado (maestra o doctorado)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as039F      0         = "Ninguno"
                       1         = "Como 10 libros"
                       2         = "Como 25 libros"
                       3         = "Como 50 libros"
                       4         = "Ms de 100 libros"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as040F      0         = "S"
                       1         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as041F      0         = "No tiene servicio mdico"
                       1         = "Seguro Popular, centro de salud, farmacia o dispensario"
                       2         = "IMSS, ISSSTE, o instituciones equivalentes"
                       3         = "Servicio Privado"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as042F      0         = "Ama de casa"
                       1         = "Ocupaciones bsicas (albail, pen, campesina, comerciante no establecida, pescadora, minera, otra)"
                       2         = "Trabajadora manual (obrera, plomera, electricista, carpintera, jardinera, zapatera, etctera)"
                       3         = "Empleada de servicios - asalariada (mesera, polica, soldada, marina, chofer, otro)"
                       4         = "Prestadora de servicios - empleadora o duea (comerciante establecida, restaurantera, encargada de establecimiento, etc.)"
                       5         = "Empleada de oficina (recepcionista, archivista, secretaria, capturista, burcrata, asistente, auxiliar, etctera)"
                       6         = "Tcnica superior universitario o profesional asociada (en mecnica, biotecnologa, comercializacin, mecatrnica, etc.)"
                       7         = "Profesionista (mdica, ingeniera, abogada, profesora, dentista, otra profesin)"
                       8         = "Directiva de instituciones pblicas o privadas"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE as043F      0         = "No s/No tengo mam o tutora"
                       1         = "No fue a la escuela"
                       2         = "Primaria incompleta"
                       3         = "Primaria completa"
                       4         = "Secundaria"
                       5         = "Bachillerato o preparatoria"
                       6         = "Licenciatura (carrera universitaria)"
                       7         = "Posgrado (maestra o doctorado)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as044F      0         = "No trabaja"
                       1         = "Ocupaciones elementales (albail, pen, campesino, comerciante no establecido, pescador, minero, otro)"
                       2         = "Trabajador manual (obrero, plomero, electricista, carpintero, jardinero, zapatero, etctera)"
                       3         = "Empleado de servicios - asalariado (mesero, polica, soldado, marino, chofer, otro)"
                       4         = "Prestador de servicios - empleador o dueo (comerciante establecido, restaurantero, encargado de establecimiento, etc.)"
                       5         = "Empleado de oficina (recepcionista, archivista, secretario, capturista, burcrata, asistente, auxiliar, etc.)"
                       6         = "Tcnico superior universitario o profesional asociado (en mecnica, biotecnologa, comercializacin, mecatrnica, etc.)"
                       7         = "Profesionista (mdico, ingeniero, abogado, profesor, dentista, otra profesin)"
                       8         = "Directivo de instituciones pblicas o privadas"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE as045F      0         = "No s/No tengo pap o tutor"
                       1         = "No fue a la escuela"
                       2         = "Primaria incompleta"
                       3         = "Primaria completa"
                       4         = "Secundaria"
                       5         = "Bachillerato o preparatoria"
                       6         = "Licenciatura (carrera universitaria)"
                       7         = "Posgrado (maestra o doctorado)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as046F      0         = "Ninguno"
                       1         = "1"
                       2         = "2"
                       3         = "3 o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as47_49F    1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as050F      1         = "De 0 a 3"
                       2         = "Entre 4 y 5"
                       3         = "Entre 6 y 7"
                       4         = "Entre 8 y 9"
                       5         = "Entre 10 y 15"
                       6         = "Entre 16 y 25"
                       7         = "26 focos o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as051F      0         = "S"
                       1         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as052F      1         = "S"
                       0         = "No"
                       2         = "No s"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as053F      3         = "Nunca o casi nunca"
                       2         = "Pocas veces"
                       1         = "Frecuentemente"
                       0         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as054F      0         = "Nunca o casi nunca"
                       1         = "Pocas veces"
                       2         = "Frecuentemente"
                       3         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as55_56F    3         = "Nunca o casi nunca"
                       2         = "Pocas veces"
                       1         = "Frecuentemente"
                       0         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as57_59F    1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as060F      1         = "Mala"
                       2         = "Regular"
                       3         = "Buena"
                       4         = "Excelente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as61_62F    4         = "Nunca o casi nunca"
                       3         = "Pocas veces"
                       2         = "Frecuentemente"
                       1         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as63_76F    0         = "Nunca o casi nunca"
                       1         = "Pocas veces"
                       2         = "Frecuentemente"
                       3         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as077F      1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as078F      0         = "Ninguno de los dos"
                       1         = "Pap"
                       2         = "Mam"
                       3         = "Ambos"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as079F      0         = "No lo s"
                       1         = "No lo voy a hacer"
                       2         = "Tal vez lo haga"
                       3         = "S, un da voy a emigrar a otro pas"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE as080F      0         = "No lo s"
                       1         = "No pienso hacerlo"
                       2         = "Al terminar una carrera universitaria"
                       3         = "Al terminar la preparatoria"
                       4         = "Al terminar la secundaria"
                       5         = "Inmediatamente (antes de terminar la secundaria)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
RUN;



DATA INEE.Excale09_2008_Alum_Cuest;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $19
       id_mod             3
       mod                $4
       mageb05            $2
       estrato            $7
       entest             $6
       alumno             6
       id_instr           $16
       sexo               3
       edad               8
       edadc              3
       edadn              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       as001              3
       as002              3
       as003              3
       as004              3
       as005              3
       as006              3
       as007              3
       as008              3
       as009              3
       as010              3
       as011              3
       as012              3
       as013              3
       as014              3
       as015              3
       as016              3
       as017              3
       as018              3
       as019              3
       as020              3
       as021              3
       as022              3
       as023              3
       as024              3
       as025              3
       as026              3
       as027              3
       as028              3
       as029              3
       as030              3
       as031              3
       as032              3
       as033              3
       as034              3
       as035              3
       as036              3
       as037              3
       as038              3
       as039              3
       as040              3
       as041              3
       as042              3
       as043              3
       as044              3
       as045              3
       as046              3
       as047              3
       as048              3
       as049              3
       as050              3
       as051              3
       as052              3
       as053              3
       as054              3
       as055              3
       as056              3
       as057              3
       as058              3
       as059              3
       as060              3
       as061              3
       as062              3
       as063              3
       as064              3
       as065              3
       as066              3
       as067              3
       as068              3
       as069              3
       as070              3
       as071              3
       as072              3
       as073              3
       as074              3
       as075              3
       as076              3
       as077              3
       as078              3
       as079              3
       as080              3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
 ;

INFILE alum MISSOVER LINESIZE = 1066;
   INPUT
       nacional           1 - 1
       escuela            2 - 5
       id_ent             6 - 7
       nom_ent            8 - 26
       id_mod            27 - 27
       mod               28 - 31
       mageb05           32 - 33
       estrato           34 - 40
       entest            41 - 46
       alumno            47 - 52
       id_instr          53 - 68
       sexo              69 - 69
       edad              70 - 80
       edadc             81 - 81
       edadn             82 - 82
       edad_ac           83 - 84
       mes_nac           85 - 86
       w_alu             87 - 97
       docente           98 - 102
       as001            103 - 103
       as002            104 - 104
       as003            105 - 105
       as004            106 - 106
       as005            107 - 107
       as006            108 - 108
       as007            109 - 109
       as008            110 - 110
       as009            111 - 111
       as010            112 - 112
       as011            113 - 113
       as012            114 - 114
       as013            115 - 115
       as014            116 - 116
       as015            117 - 117
       as016            118 - 118
       as017            119 - 119
       as018            120 - 120
       as019            121 - 121
       as020            122 - 122
       as021            123 - 123
       as022            124 - 124
       as023            125 - 125
       as024            126 - 126
       as025            127 - 127
       as026            128 - 128
       as027            129 - 129
       as028            130 - 130
       as029            131 - 131
       as030            132 - 132
       as031            133 - 133
       as032            134 - 134
       as033            135 - 135
       as034            136 - 136
       as035            137 - 137
       as036            138 - 138
       as037            139 - 139
       as038            140 - 140
       as039            141 - 141
       as040            142 - 142
       as041            143 - 143
       as042            144 - 145
       as043            146 - 146
       as044            147 - 148
       as045            149 - 149
       as046            150 - 150
       as047            151 - 151
       as048            152 - 152
       as049            153 - 153
       as050            154 - 154
       as051            155 - 155
       as052            156 - 156
       as053            157 - 157
       as054            158 - 158
       as055            159 - 159
       as056            160 - 160
       as057            161 - 161
       as058            162 - 162
       as059            163 - 163
       as060            164 - 164
       as061            165 - 165
       as062            166 - 166
       as063            167 - 167
       as064            168 - 168
       as065            169 - 169
       as066            170 - 170
       as067            171 - 171
       as068            172 - 172
       as069            173 - 173
       as070            174 - 174
       as071            175 - 175
       as072            176 - 176
       as073            177 - 177
       as074            178 - 178
       as075            179 - 179
       as076            180 - 180
       as077            181 - 181
       as078            182 - 182
       as079            183 - 183
       as080            184 - 184
       wvarstrr         185 - 186
       w_fstr1          187 - 197
       w_fstr2          198 - 208
       w_fstr3          209 - 219
       w_fstr4          220 - 230
       w_fstr5          231 - 241
       w_fstr6          242 - 252
       w_fstr7          253 - 263
       w_fstr8          264 - 274
       w_fstr9          275 - 285
       w_fstr10         286 - 296
       w_fstr11         297 - 307
       w_fstr12         308 - 318
       w_fstr13         319 - 329
       w_fstr14         330 - 340
       w_fstr15         341 - 351
       w_fstr16         352 - 362
       w_fstr17         363 - 373
       w_fstr18         374 - 384
       w_fstr19         385 - 395
       w_fstr20         396 - 406
       w_fstr21         407 - 417
       w_fstr22         418 - 428
       w_fstr23         429 - 439
       w_fstr24         440 - 450
       w_fstr25         451 - 461
       w_fstr26         462 - 472
       w_fstr27         473 - 483
       w_fstr28         484 - 494
       w_fstr29         495 - 505
       w_fstr30         506 - 516
       w_fstr31         517 - 527
       w_fstr32         528 - 538
       w_fstr33         539 - 549
       w_fstr34         550 - 560
       w_fstr35         561 - 571
       w_fstr36         572 - 582
       w_fstr37         583 - 593
       w_fstr38         594 - 604
       w_fstr39         605 - 615
       w_fstr40         616 - 626
       w_fstr41         627 - 637
       w_fstr42         638 - 648
       w_fstr43         649 - 659
       w_fstr44         660 - 670
       w_fstr45         671 - 681
       w_fstr46         682 - 692
       w_fstr47         693 - 703
       w_fstr48         704 - 714
       w_fstr49         715 - 725
       w_fstr50         726 - 736
       w_fstr51         737 - 747
       w_fstr52         748 - 758
       w_fstr53         759 - 769
       w_fstr54         770 - 780
       w_fstr55         781 - 791
       w_fstr56         792 - 802
       w_fstr57         803 - 813
       w_fstr58         814 - 824
       w_fstr59         825 - 835
       w_fstr60         836 - 846
       w_fstr61         847 - 857
       w_fstr62         858 - 868
       w_fstr63         869 - 879
       w_fstr64         880 - 890
       w_fstr65         891 - 901
       w_fstr66         902 - 912
       w_fstr67         913 - 923
       w_fstr68         924 - 934
       w_fstr69         935 - 945
       w_fstr70         946 - 956
       w_fstr71         957 - 967
       w_fstr72         968 - 978
       w_fstr73         979 - 989
       w_fstr74         990 - 1000
       w_fstr75        1001 - 1011
       w_fstr76        1012 - 1022
       w_fstr77        1023 - 1033
       w_fstr78        1034 - 1044
       w_fstr79        1045 - 1055
       w_fstr80        1056 - 1066
 ;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       mageb05     = "ndice de marginacin urbana 2005"
       estrato     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       alumno      = "Identificador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       edad        = "Edad del alumno al mes de mayo de 2008, en aos (al momento de la aplicacin)"
       edadc       = "Edad del alumno al mes de mayo de 2008, codificada (al momento de la aplicacin)"
       edadn       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       as001       = "Qu lengua aprendiste a hablar primero?"
       as002       = "Qu lengua hablas en tu casa la mayor parte del tiempo?"
       as003       = "En tu casa vive algn familiar que hable alguna lengua indgena? (nhuatl, maya, purpecha, mixteco, otom u otra)"
       as004       = "Con cul de tus padres vives?"
       as005       = "Tus padres o tutores estn pendientes de tus calificaciones?"
       as006       = "Tus padres o tutores estn pendientes de los materiales que necesitas para la escuela?"
       as007       = "Tus padres o tutores te ayudan a hacer la tarea cuando lo necesitas?"
       as008       = "Cuntas tareas hiciste el bimestre pasado?"
       as009       = "Aproximadamente, cuntos das a la semana haces tareas o estudias?"
       as010       = "En general, cuntas horas al da dedicas a estudiar o hacer tareas fuera de la escuela?"
       as011       = "Cuntas pginas al da tienes que leer para realizar tus actividades escolares, dentro y fuera de la escuela?"
       as012       = "Lo que aprendes en la escuela te ayuda en tu vida diaria?"
       as013       = "Cundo no entiendes algo en clase, buscas informacin en otros lugares (libros, Internet, revistas, etctera)?"
       as014       = "Cuando te interesa algo que aprendiste en clase, buscas ms informacin en otros lugares (libros, Internet, revistas, etctera)?"
       as015       = "Realizas todas las actividades que te dejan tus maestros, an cuando no sean tomadas en cuenta para tu calificacin?"
       as016       = "Pones atencin a tu maestro durante la clase?"
       as017       = "Durante la semana pasada, cunto tiempo dedicaste a ayudar a tu familia a realizar alguna actividad sin pago alguno (labores domsticas, atender un negocio familiar, labores del campo, etctera)?"
       as018       = "Realizas un trabajo por el cual recibes algn pago?"
       as019       = "De qu tipo era la escuela primaria donde estudiaste?"
       as020       = "La escuela primaria en la que estudiaste, de qu modalidad era?"
       as021       = "En la escuela primaria donde estudiaste:"
       as022       = "Estudiaste todos los grados de primaria en la misma escuela?"
       as023       = "Cuntos aos repetiste en la primaria?"
       as024       = "Qu ao escolar repetiste en la primaria? (Si repetiste ms de uno, seala el primer ao repetido)"
       as025       = "Cuntas materias has reprobado en secundaria?"
       as026       = "Consumes alguna bebida que contenga alcohol? (cerveza, vino, ron, tequila u otra)"
       as027       = "Desde qu edad la consumes?"
       as028       = "Fumas cigarros de tabaco?"
       as029       = "Desde qu edad los fumas?"
       as030       = "Alguna vez has consumido algn tipo de droga? (cocana, inhalantes, anfetaminas, etctera)"
       as031       = "En este ao escolar alguno de tus compaeros llev a la escuela algn objeto peligroso o un arma (pistola, navaja, etctera)?"
       as032       = "En este ao escolar ocurrieron peleas a golpes entre alumnos?"
       as033       = "En este ao escolar algn estudiante o un grupo de estudiantes da las instalaciones, el mobiliario o equipo de la escuela (pintas, graffiti, descomponer chapas de puertas, etctera)?"
       as034       = "En este ao escolar algn estudiante o grupo de estudiantes rob dinero o pertenencias dentro de la escuela?"
       as035       = "En este ao escolar algn estudiante o grupo de estudiantes consumi alcohol o drogas dentro de la escuela?"
       as036       = "En este ao escolar algn estudiante o grupo de estudiantes agredi verbalmente a otros estudiantes (burlas, apodos, sobrenombres, insultos, etctera)?"
       as037       = "Hasta qu nivel educativo te gustara estudiar?"
       as038       = "Hasta qu nivel educativo les gustara a tus padres o tutores que estudiaras?"
       as039       = "Aproximadamente, Cuntos libros hay en tu casa? (No incluyas revistas, ni peridicos ni tus libros escolares)"
       as040       = "Recientemente, alguna de las personas con quienes vives dej de estudiar por problemas econmicos?"
       as041       = "A qu tipo de servicios mdicos acude tu familia?"
       as042       = "En que trabaja tu mam o tutora? (Si la respuesta no se encuentra en las opciones, por favor elija la ms semejante)"
       as043       = "Cul es el nivel mximo de estudios que trmino tu mam o tutora?"
       as044       = "En que trabaja tu pap o tutor? (Si la respuesta no se encuentra en las opciones, por favor elija la ms semejante)"
       as045       = "Cul es el nivel  mximo de estudios que trmino tu pap o tutor?"
       as046       = "Cuntos cuartos de bao hay en la casa donde vives?"
       as047       = "En la casa donde vives hay lnea telefnica?"
       as048       = "En la casa donde vives hay internet?"
       as049       = "En la casa donde vives tienen un automvil?"
       as050       = "Cuntos focos hay en la casa donde vives?"
       as051       = "Tu familia recibe o ha recibido apoyo del programa Oportunidades?"
       as052       = "Actualmente, tienes beca del programa Oportunidades?"
       as053       = "Qu tan seguido faltan tus maestros a clases?"
       as054       = "Tus maestros empiezan sus clases puntualmente?"
       as055       = "Tus maestros dejan solo a tu grupo en horas de clase?"
       as056       = "Tus maestros platican con otros adultos sobre cosas que no son de la escuela durante las clases?"
       as057       = "Tus maestros les exigen que se esfuercen mucho?"
       as058       = "Tus maestros los alientan a que sigan estudiando despus de terminar la secundaria?"
       as059       = "Tus maestros les hacen sentir confianza en que pueden aprender todo lo que les ensean?"
       as060       = "Cmo es la disciplina de la mayora de tus compaeros durante las clases?"
       as061       = "Tus maestros interrumpen sus clases por razones de indisciplina?"
       as062       = "Hay tanto desorden dentro de tu saln que no se puede poner atencin en las clases?"
       as063       = "Tus maestros te dicen cmo corregir tus errores?"
       as064       = "Las tareas, trabajos o ejercicios, que dejan, tus maestros, se revisan de forma colectiva en clase?"
       as065       = "Entiendes las explicaciones de tus maestros?"
       as066       = "Tus maestros dan ejemplos fciles para ayudarlos a entender?"
       as067       = "Tus maestros utilizan material adicional para ayudarte a comprender mejor?"
       as068       = "Tus maestros te dejan trabajos o investigaciones para realizar en la biblioteca?"
       as069       = "Tus maestros te explican cmo hacer los trabajos que te dejan?"
       as070       = "Tus maestros te explican los criterios con los que calificarn los trabajos?"
       as071       = "Tus maestros respetan sus criterios de calificacin?"
       as072       = "Tus maestros te permiten expresar tus opiniones y dudas?"
       as073       = "Tus maestros promueven que los alumnos participen en clase?"
       as074       = "Tus maestros preparan bien sus clases?"
       as075       = "Tus maestros se llevan bien entre ellos?"
       as076       = "Tus maestros tratan bien a los alumnos?"
       as077       = "Tienes algn pariente que haya emigrado a otro pas?"
       as078       = "Cul de tus paps ha emigrado a otro pas?"
       as079       = "Consideras emigrar a otro pas?"
       as080       = "Si piensas emigrar algn da, cundo lo haras?"
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char19.
       id_mod             id_modF.
       mod                $modF.
       mageb05            mageb05F.
       estrato            $char7.
       entest             $char6.
       alumno             5.
       id_instr           $char16.
       sexo               sexoF.
       edad               edadF.
       edadc              edadcF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       as001              as1_2F.
       as002              as1_2F.
       as003              as003F.
       as004              as004F.
       as005              as5_7F.
       as006              as5_7F.
       as007              as5_7F.
       as008              as008F.
       as009              as009F.
       as010              as010F.
       as011              as011F.
       as012              as12_16F.
       as013              as12_16F.
       as014              as12_16F.
       as015              as12_16F.
       as016              as12_16F.
       as017              as017F.
       as018              as018F.
       as019              as019F.
       as020              as020F.
       as021              as021F.
       as022              as022F.
       as023              as023F.
       as024              as024F.
       as025              as025F.
       as026              as026F.
       as027              as027F.
       as028              as028F.
       as029              as029F.
       as030              as030F.
       as031              as31_36F.
       as032              as31_36F.
       as033              as31_36F.
       as034              as31_36F.
       as035              as31_36F.
       as036              as31_36F.
       as037              as037F.
       as038              as038F.
       as039              as039F.
       as040              as040F.
       as041              as041F.
       as042              as042F.
       as043              as043F.
       as044              as044F.
       as045              as045F.
       as046              as046F.
       as047              as47_49F.
       as048              as47_49F.
       as049              as47_49F.
       as050              as050F.
       as051              as051F.
       as052              as052F.
       as053              as053F.
       as054              as054F.
       as055              as55_56F.
       as056              as55_56F.
       as057              as57_59F.
       as058              as57_59F.
       as059              as57_59F.
       as060              as060F.
       as061              as61_62F.
       as062              as61_62F.
       as063              as63_76F.
       as064              as63_76F.
       as065              as63_76F.
       as066              as63_76F.
       as067              as63_76F.
       as068              as63_76F.
       as069              as63_76F.
       as070              as63_76F.
       as071              as63_76F.
       as072              as63_76F.
       as073              as63_76F.
       as074              as63_76F.
       as075              as63_76F.
       as076              as63_76F.
       as077              as077F.
       as078              as078F.
       as079              as079F.
       as080              as080F.
       wvarstrr           2.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(78)
                   as001 as002 as003 as004 as005 as006 as007 as008 as009 as010
                   as011 as012 as013 as014 as015 as016 as017 as018 as019 as020
                   as021 as022 as023 as024 as025 as026 as027 as028 as029 as030
                   as031 as032 as033 as034 as035 as036 as037 as038 as039 as040
                   as041 as043 as045 as046 as047 as048 as049 as050 as051 as052
                   as053 as054 as055 as056 as057 as058 as059 as060 as061 as062
                   as063 as064 as065 as066 as067 as068 as069 as070 as071 as072
                   as073 as074 as075 as076 as077 as078 as079 as080;
   DO  i=1 TO 78;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;


   ARRAY perdidos4(2)
                    as042 as044;
   DO  i=1 TO 2;
          IF perdidos4{i} = 98   THEN  perdidos4{i} = .M;
          IF perdidos4{i} = 99   THEN  perdidos4{i} = .S;
   END;

   drop i;
RUN;
